@@ -1,3 +1,3 @@
-from .advanced_ml_tab import AdvancedMLTabWithPlots
+from .advanced_ml_tab import AdvancedMLTabWithFeatureSelection
 from .batch_processor_tab import BatchProcessingTab 
 from .feature_selection_tab import FeatureSelectionTab
\ No newline at end of file
